@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef FR_WINDOW_H
@@ -28,7 +27,6 @@
 #include "typedefs.h"
 #include "fr-archive.h"
 
-#define GCONF_NOTIFICATIONS 10
 
 enum {
 	COLUMN_FILE_DATA,
@@ -94,8 +92,13 @@ struct _FrWindowClass
 
 	/*<signals>*/
 
-	void (*archive_loaded) (FrWindow *window,
-				gboolean  success);
+	void (*archive_loaded) (FrWindow   *window,
+				gboolean    success);
+	void (*progress)       (FrWindow   *window,
+			        double      fraction,
+			        const char *msg);
+	void (*ready)          (FrWindow   *window,
+				GError     *error);
 };
 
 GType       fr_window_get_type                  (void);
@@ -115,12 +118,14 @@ const char *fr_window_get_paste_archive_uri     (FrWindow      *window);
 gboolean    fr_window_archive_is_present        (FrWindow      *window);
 void        fr_window_archive_save_as           (FrWindow      *window,
 						 const char    *filename,
-						 const char    *password);
+						 const char    *password,
+						 gboolean       encrypt_header,
+						 guint          volume_size);
 void        fr_window_archive_reload            (FrWindow      *window);
 void        fr_window_archive_rename            (FrWindow      *window,
 						 const char    *filename);
 void        fr_window_archive_add_files         (FrWindow      *window,
-						 GList         *file_list,
+						 GList         *file_list, /* GFile list */
 						 gboolean       update);
 void        fr_window_archive_add_with_wildcard (FrWindow      *window,
 						 const char    *include_files,
@@ -273,6 +278,8 @@ void        fr_window_set_statusbar_visibility    (FrWindow   *window,
 						   gboolean    value);
 void        fr_window_set_folders_visibility      (FrWindow   *window,
 						   gboolean    value);
+void        fr_window_use_progress_dialog         (FrWindow   *window,
+						   gboolean    value);
 
 /* batch mode procedures. */
 
